@@ -39,8 +39,7 @@ import scipy.linalg as slin
 import scipy.optimize as sopt
 
 from causalnex.structure import StructureModel
-
-from .transformers import DynamicDataTransformer
+from causalnex.structure.transformers import DynamicDataTransformer
 
 
 def from_pandas_dynamic(  # pylint: disable=too-many-arguments
